@@ -183,15 +183,20 @@ proc xcircuit::makesymbol {} {
       symbol goto
 
       set itext [list {Text "spice:"} {Parameter class} {Parameter idx}]
+      set pstring ""
       foreach j $pinlabels {
-         lappend itext "%p$j"
+         lappend pstring "%p$j"
       }
-      lappend itext " %n"
+      lappend pstring "%n"
+      lappend itext [subst {Text " $pstring"}]
    } else {
       set itext [list {Text "spice:"} {Parameter class} {Parameter idx}]
+      set pstring ""
       foreach j [lrange [lindex $subckttext 0] 2 end] {
-	 lappend itext "%p$j"
+         lappend pstring "%p$j"
       }
+      lappend pstring "%n"
+      lappend itext [subst {Text " $pstring"}]
    }
 
    set y [expr -$hheight - 3 * $pinspace]
