@@ -1622,7 +1622,7 @@ void insertparam()
             sptr += strlen(sptr);
 	 }
       }
-      Wprintf(sstart);
+      Wprintf("%s", sstart);
       free(sstart);
 
       /* Need a new non-Tcl version method . . . */
