@@ -220,7 +220,7 @@ short execcommand(short pflags, char *cmdptr)
 	    func = string_to_func(_STR, NULL);
 	 }
 	 binding = binding_to_string(keywstate, func);
-	 Wprintf(binding);
+	 Wprintf("%s", binding);
 	 free(binding);
       }
       else if (args == 0)
