@@ -284,8 +284,8 @@ void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
          ggen = *(nextselect->thisinst->thisobject->plist + *(nextselect->selectlist));
 	 while (rselect != NULL) {
 	    nextselect = rselect->next;
-	    free(rselect);
             free(rselect->selectlist);
+	    free(rselect);
 	    rselect = nextselect;
 	 }
       }
@@ -343,7 +343,7 @@ void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
 	    }
 	    sprintf(sptr, "in %s", nettop->name);
 	 }
-	 Wprintf(_STR2);
+	 Wprintf("%s", _STR2);
 
 #ifdef TCL_WRAPPER
 	 Tcl_SetObjResult(xcinterp, Tcl_NewStringObj(snew, strlen(snew)));
@@ -471,7 +471,7 @@ void dopintype(xcWidget w, pointertype mode, caddr_t calldata)
    if (savetype >= 0) {
       unselect_all();
       drawarea(NULL, NULL, NULL);
-      Wprintf(typestr);
+      Wprintf("%s", typestr);
    }
    else {
       Wprintf("No labels selected.");
@@ -678,49 +678,6 @@ void collectsubschems(int toppage)
    free((char *)pagelist);
 }
 
-/*--------------------------------------------------------*/
-/* Copy label to corresponding schematic/symbol		  */
-/*--------------------------------------------------------*/
-
-void copypinlabel(labelptr pinlab)
-{
-   labelptr *newlabel, tlabel;
-   genericptr *tgen;
-   objectptr schemobj = topobject->symschem;
-
-   if (areastruct.schemon && schemobj != NULL && (pinlab->pin == LOCAL)) {
-
-      /* If this pin already exists, don't copy it */
-
-      for (tgen = schemobj->plist; tgen < schemobj->plist + schemobj->parts;
-		tgen++) {
-         if (IS_LABEL(*tgen)) {
-	    tlabel = TOLABEL(tgen);
-	    if (!stringcomp(tlabel->string, pinlab->string)) return;
-         }
-      }
-
-      NEW_LABEL(newlabel, schemobj);
-      (*newlabel)->pin = pinlab->pin;
-      (*newlabel)->rotation = pinlab->rotation;
-      (*newlabel)->justify = pinlab->justify;
-      (*newlabel)->color = pinlab->color;
-      (*newlabel)->scale = pinlab->scale;
-      (*newlabel)->string = stringcopy(pinlab->string);
-      (*newlabel)->passed = NULL;
-
-      /* place label just outside bounding box, then recompute bbox */
-
-      (*newlabel)->position.x = schemobj->bbox.lowerleft.x + (schemobj->bbox.width >> 1);
-      (*newlabel)->position.y = schemobj->bbox.lowerleft.y - TEXTHEIGHT
-	   * (*newlabel)->scale;
-      schemobj->parts++;
-      incr_changes(schemobj);
-      invalidate_netlist(schemobj);
-      singlebbox(ENDPART);
-   }
-}
-
 /*-------------------------------------------------------*/
 /* Check if top-level page is the same name as a library */
 /* object; if so, connect it.				 */
